==> ejc-sddjsorg-api-3.0.0-20211015.112102-15-sources.jar: com/ejianc/business/production/vo/TransferInfoVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权登记-划转方案信息
 * 
 * @author generator
 * 
 */
public class TransferInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long pid; // 主表id
    private java.lang.String inOrgName; // 划入方名称
    private java.lang.String inOrgCode; // 划入方统一社会信用代码
    private java.lang.Long outOrg; // 划出方名称
    private java.lang.String outOrgName; // 划出方名称
    private java.lang.String outOrgCode; // 划出方统一社会信用代码
    private java.math.BigDecimal proportion; // 划转股权比例(%)
    private java.util.Date transferDate; // 划转基准日
    

    /**
     * 主表id
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 划入方名称
     */
    public java.lang.String getInOrgName() {
        return inOrgName;
    }

    /**
     * 划入方名称
     */
    public void setInOrgName(java.lang.String inOrgName) {
        this.inOrgName = inOrgName;
    }
    /**
     * 划入方统一社会信用代码
     */
    public java.lang.String getInOrgCode() {
        return inOrgCode;
    }

    /**
     * 划入方统一社会信用代码
     */
    public void setInOrgCode(java.lang.String inOrgCode) {
        this.inOrgCode = inOrgCode;
    }
    /**
     * 划出方名称
     */
    public java.lang.Long getOutOrg() {
        return outOrg;
    }

    /**
     * 划出方名称
     */
    public void setOutOrg(java.lang.Long outOrg) {
        this.outOrg = outOrg;
    }
    /**
     * 划出方名称
     */
    public java.lang.String getOutOrgName() {
        return outOrgName;
    }

    /**
     * 划出方名称
     */
    public void setOutOrgName(java.lang.String outOrgName) {
        this.outOrgName = outOrgName;
    }
    /**
     * 划出方统一社会信用代码
     */
    public java.lang.String getOutOrgCode() {
        return outOrgCode;
    }

    /**
     * 划出方统一社会信用代码
     */
    public void setOutOrgCode(java.lang.String outOrgCode) {
        this.outOrgCode = outOrgCode;
    }
    /**
     * 划转股权比例(%)
     */
    public java.math.BigDecimal getProportion() {
        return proportion;
    }

    /**
     * 划转股权比例(%)
     */
    public void setProportion(java.math.BigDecimal proportion) {
        this.proportion = proportion;
    }
    /**
     * 划转基准日
     */
    public java.util.Date getTransferDate() {
        return transferDate;
    }

    /**
     * 划转基准日
     */
    public void setTransferDate(java.util.Date transferDate) {
        this.transferDate = transferDate;
    }
    
}

==> ejc-sddjsorg-api-3.0.0-20211021.092457-46-sources.jar: com/ejianc/business/production/vo/TransferInfoVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权登记-划转方案信息
 * 
 * @author generator
 * 
 */
public class TransferInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long pid; // 主表id
    private java.lang.String inOrgId; // 划入方名称
    private java.lang.String inOrgName; // 划入方名称
    private java.lang.String inOrgCode; // 划入方统一社会信用代码
    private java.lang.Long outOrg; // 划出方名称
    private java.lang.String outOrgName; // 划出方名称
    private java.lang.String outOrgCode; // 划出方统一社会信用代码
    private java.math.BigDecimal proportion; // 划转股权比例(%)
    private java.util.Date transferDate; // 划转基准日
    

    /**
     * 主表id
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 划入方名称
     */
    public java.lang.String getInOrgName() {
        return inOrgName;
    }

    /**
     * 划入方名称
     */
    public void setInOrgName(java.lang.String inOrgName) {
        this.inOrgName = inOrgName;
    }
    /**
     * 划入方统一社会信用代码
     */
    public java.lang.String getInOrgCode() {
        return inOrgCode;
    }

    /**
     * 划入方统一社会信用代码
     */
    public void setInOrgCode(java.lang.String inOrgCode) {
        this.inOrgCode = inOrgCode;
    }
    /**
     * 划出方名称
     */
    public java.lang.Long getOutOrg() {
        return outOrg;
    }

    /**
     * 划出方名称
     */
    public void setOutOrg(java.lang.Long outOrg) {
        this.outOrg = outOrg;
    }
    /**
     * 划出方名称
     */
    public java.lang.String getOutOrgName() {
        return outOrgName;
    }

    /**
     * 划出方名称
     */
    public void setOutOrgName(java.lang.String outOrgName) {
        this.outOrgName = outOrgName;
    }
    /**
     * 划出方统一社会信用代码
     */
    public java.lang.String getOutOrgCode() {
        return outOrgCode;
    }

    /**
     * 划出方统一社会信用代码
     */
    public void setOutOrgCode(java.lang.String outOrgCode) {
        this.outOrgCode = outOrgCode;
    }
    /**
     * 划转股权比例(%)
     */
    public java.math.BigDecimal getProportion() {
        return proportion;
    }

    /**
     * 划转股权比例(%)
     */
    public void setProportion(java.math.BigDecimal proportion) {
        this.proportion = proportion;
    }
    /**
     * 划转基准日
     */
    public java.util.Date getTransferDate() {
        return transferDate;
    }

    /**
     * 划转基准日
     */
    public void setTransferDate(java.util.Date transferDate) {
        this.transferDate = transferDate;
    }

    public String getInOrgId() {
        return inOrgId;
    }

    public void setInOrgId(String inOrgId) {
        this.inOrgId = inOrgId;
    }
}
